# zhTW2Num

## Summary
* This tool is for converting the number texts of Traditional Chinese into float
* Float value is supported

## How to use it

```
text = '金額總共兩千零二十元'
res = zhTW2Num(text)
print(res) # 2020.0
text = '長度二點零五公分
res = zhTW2Num(text)
print(res) # 2.05

```

